@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
 our $DATE = '2015-12-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,6 +33,12 @@ $SPEC{zodiac_of} = {
         },
         {
             summary => 'Multiple dates',
+            description => <<'_',
+
+If multiple dates are specified, the result will include the date to
+differentiate which zodiac belongs to which date.
+
+_
             args => {dates=>['2015-12-17','2015-12-29']},
             result => [["2015-12-17","sagittarius"], ["2015-12-29","capricornus"]],
             test => 0,
@@ -123,7 +129,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.06 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-12-18.
+This document describes version 0.07 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-12-18.
 
 =head1 DESCRIPTION
 
@@ -146,9 +152,15 @@ Show Chinese zodiac for a date.
 
 Examples:
 
- chinese_zodiac_of( dates => ["1980-02-17"]); # -> "monkey (metal)"
- chinese_zodiac_of( dates => ["2015-12-17", "2016-12-17"]);
+=over
 
+=item * Example #1:
+
+ chinese_zodiac_of( dates => ["1980-02-17"]); # -> "monkey (metal)"
+
+=item * Multiple dates:
+
+ chinese_zodiac_of( dates => ["2015-12-17", "2016-12-17"]);
 
 Result:
 
@@ -156,8 +168,8 @@ Result:
    ["2015-12-17", "goat (wood)"],
    ["2016-12-17", "monkey (fire)"],
  ]
-Multiple dates.
 
+=back
 
 This function is not exportable.
 
@@ -180,15 +192,24 @@ Show zodiac for a date.
 
 Examples:
 
- zodiac_of( dates => ["2015-06-15"]); # -> "gemini"
- zodiac_of( dates => ["2015-12-17", "2015-12-29"]);
+=over
 
+=item * Example #1:
+
+ zodiac_of( dates => ["2015-06-15"]); # -> "gemini"
+
+=item * Multiple dates:
+
+ zodiac_of( dates => ["2015-12-17", "2015-12-29"]);
 
 Result:
 
  [["2015-12-17", "sagittarius"], ["2015-12-29", "capricornus"]]
-Multiple dates.
 
+If multiple dates are specified, the result will include the date to
+differentiate which zodiac belongs to which date.
+
+=back
 
 This function is not exportable.
 
